@@ -672,12 +672,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'Failed to get_fund_industry_exposure {e} from {FundIndicatorGroup.__tablename__}')
                 return pd.DataFrame([])
 
-
-    def get_fof_nav(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_nav(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 query = session.query(
                     FOFNav,
+                ).filter(
+                    FOFNav.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -703,11 +704,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {FOFNav.__tablename__}')
                 return False
 
-    def get_fof_nav_public(self, fof_id_list: Tuple[str] = ()):
+    def get_fof_nav_public(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
                 query = session.query(
                     FOFNavPublic,
+                ).filter(
+                    FOFNavPublic.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -875,11 +878,13 @@ class DerivedDataApi(metaclass=Singleton):
                 print(f'failed to delete data <err_msg> {e} from {HedgeFundInvestorPurAndRedemp.__tablename__}')
                 return False
 
-    def get_hedge_fund_investor_div_carry(self, fof_id_list: Tuple[str] = ()):
+    def get_hedge_fund_investor_div_carry(self, manager_id: str, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     HedgeFundInvestorDivAndCarry,
+                ).filter(
+                    HedgeFundInvestorDivAndCarry.manager_id == manager_id,
                 )
                 if fof_id_list:
                     query = query.filter(
@@ -954,6 +959,10 @@ class DerivedDataApi(metaclass=Singleton):
 
     def get_industry_stock_ret_and_size(self, begin_date, end_date, time_para):
         try:
+            def process_x(x):
+                x.loc[:,'weight'] = x.total_share / x.total_share.sum()
+                x = x[x.weight >= 0.015]
+                return x
             # 建议只用短时间，上时间慢
             raw_api = RawDataApi()
             basic_api = BasicDataApi()
@@ -971,6 +980,10 @@ class DerivedDataApi(metaclass=Singleton):
             total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'])
             total_share = total_share.pivot_table(index='stock_id',columns='datetime',values='total_share')
             total_share.columns = ['total_share']
+            groupby_df = stock_df.join(total_share).copy()
+            stock_df = groupby_df.groupby('industry_2').apply(lambda x: process_x(x))
+            stock_df = stock_df.drop(columns=['industry_2']).reset_index().set_index('stock_id')
+            stock_list = stock_df.index.tolist()
             stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,stock_list=stock_list,columns=['close'])
             last_date = sorted(stock_price.datetime.unique().tolist())[-1]
             last_price = stock_price[stock_price['datetime'] == last_date]
@@ -1114,6 +1127,21 @@ class DerivedDataApi(metaclass=Singleton):
             am.columns=['均值']
             df = pd.concat([a1,a2,a3,a4,a5,am],axis=1).sort_index().dropna(axis=0,how='all')
             df.index.name = 'datetime'
+            
+            cols = df.columns.tolist()
+            cols = [i for i in cols if i != '均值']
+            for col in cols:
+                df_i = df[[col]].copy()
+                df_i.loc[:,'con'] = df_i[col].isnull()
+                df_i.loc[:,'last_con'] = df_i[col].shift(-1).isnull()
+                dts = df_i[( ~df_i.con) & (df_i.last_con)].index.tolist()
+                for i in dts:
+                    if df.loc[i:].shape[0] == 1:
+                        continue
+                    else:
+                        i = df.loc[i:].index[1]
+                        df.loc[i,col] = index_risk.risk_value.loc[i]
+            
             title = index_name +title_dic[valuation_type]
             data = {
                 'data':df,
