@@ -24,15 +24,15 @@ class HedgeFundDataManager(metaclass=Singleton):
     def __init__(self):
         pass
 
-    def _get_total_share(self, fof_id: str, investor_id: str = '', exclude1: List[int] = [], exclude2: List[str] = []) -> Tuple[float, pd.DataFrame]:
-        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp([fof_id])
+    def _get_total_share(self, manager_id: str, fof_id: str, investor_id: str = '', exclude1: List[int] = [], exclude2: List[str] = []) -> Tuple[float, pd.DataFrame]:
+        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
         assert part1 is not None, '!!!!'
         part1 = part1[~part1.id.isin(exclude1)]
         part1_total_share = part1.share_changed.sum()
         if investor_id:
             part1 = part1.loc[part1.investor_id == investor_id, :]
 
-        part2 = DerivedDataApi().get_hedge_fund_investor_div_carry([fof_id])
+        part2 = DerivedDataApi().get_hedge_fund_investor_div_carry(manager_id, [fof_id])
         part2 = part2[~part2.id.isin(exclude2)]
         assert part2 is not None, '!!!!'
         part2_total_share = part2.share_changed.sum()
@@ -43,10 +43,10 @@ class HedgeFundDataManager(metaclass=Singleton):
         share_separate = part1[['investor_id', 'share_changed']].groupby(by='investor_id', sort=False).sum().add(part2[['investor_id', 'share_changed']].groupby(by='investor_id', sort=False).sum(), fill_value=0)
         return total_share, share_separate
 
-    def _refresh_datas_after_updating(self, fof_id: str, investor_id: str, datetime):
+    def _refresh_datas_after_updating(self, manager_id: str, fof_id: str, investor_id: str, datetime):
         datetime: datetime.date = pd.to_datetime(datetime, infer_datetime_format=True).date()
 
-        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp([fof_id])
+        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
         assert part1 is not None, '!!!!'
         part1 = part1[part1.investor_id == investor_id].sort_values(by='datetime')
         last_valid_share: float = part1[part1.datetime <= datetime].iloc[-1, :].share_after_trans
@@ -57,6 +57,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         Session = sessionmaker(DerivedDatabaseConnector().get_engine())
         db_session = Session()
         for row in db_session.query(HedgeFundInvestorPurAndRedemp).filter(
+            HedgeFundInvestorPurAndRedemp.manager_id == manager_id,
             HedgeFundInvestorPurAndRedemp.fof_id == fof_id,
             HedgeFundInvestorPurAndRedemp.investor_id == investor_id,
             HedgeFundInvestorPurAndRedemp.datetime > datetime,
@@ -65,12 +66,12 @@ class HedgeFundDataManager(metaclass=Singleton):
         db_session.commit()
         db_session.close()
 
-    def _calc_share_details(self, fof_info, fof_id: str, investor_id: str) -> List[Dict[str, Any]]:
-        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp([fof_id])
+    def _calc_share_details(self, fof_info, manager_id: str, fof_id: str, investor_id: str) -> List[Dict[str, Any]]:
+        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
         assert part1 is not None, '!!!!'
         part1 = part1.loc[part1.investor_id == investor_id, ['datetime', 'event_type', 'share_changed', 'net_asset_value', 'acc_unit_value']]
 
-        part2 = DerivedDataApi().get_hedge_fund_investor_div_carry([fof_id])
+        part2 = DerivedDataApi().get_hedge_fund_investor_div_carry(manager_id, [fof_id])
         assert part2 is not None, '!!!!'
         part2 = part2.loc[(part2.investor_id == investor_id) & (part2.event_type.isin([FOFTradeStatus.DIVIDEND_VOLUME, FOFTradeStatus.DEDUCT_REWARD])), ['datetime', 'event_type', 'share_changed', 'net_asset_value', 'acc_unit_value']]
 
@@ -132,7 +133,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         -------
         throw excepion if failed, or return id (an integer) if succeed
         '''
-        fof_info = BasicDataApi().get_fof_info(fof_id_list=[datas['fof_id']])
+        fof_info = BasicDataApi().get_fof_info(datas['manager_id'], fof_id_list=[datas['fof_id']])
         assert fof_info is not None, '!!!!'
         assert fof_info.shape[0] == 1, f"invalid fof id {[datas['fof_id']]}"
         fof_info = fof_info.iloc[-1, :]
@@ -153,7 +154,7 @@ class HedgeFundDataManager(metaclass=Singleton):
 
             # 计算业绩报酬计提
             carry_sum = 0
-            share_details = self._calc_share_details(fof_info, datas['fof_id'], datas['investor_id'])
+            share_details = self._calc_share_details(fof_info, datas['manager_id'], datas['fof_id'], datas['investor_id'])
             for one in share_details:
                 if math.isclose(one['share'], 0):
                     continue
@@ -173,7 +174,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         else:
             raise ValueError(f'invalid event_type {event_type}')
 
-        _, share_separate = self._get_total_share(datas['fof_id'], datas['investor_id'], exclude1=[datas['id']] if 'id' in datas else [])
+        _, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['investor_id'], exclude1=[datas['id']] if 'id' in datas else [])
         try:
             datas['share_after_trans'] = float(share_separate.at[datas['investor_id'], 'share_changed']) + datas['share_changed']
         except KeyError:
@@ -192,7 +193,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             the_id = sql_obj.id
         # df.to_sql(HedgeFundInvestorPurAndRedemp.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
         if 'id' in datas:
-            self._refresh_datas_after_updating(datas['fof_id'], datas['investor_id'], datas['datetime'])
+            self._refresh_datas_after_updating(datas['manager_id'], datas['fof_id'], datas['investor_id'], datas['datetime'])
         return the_id
 
     def _calc_carry(self, nav: float, water_line: float, fee_type: str, fee_desc: str) -> float:
@@ -234,7 +235,7 @@ class HedgeFundDataManager(metaclass=Singleton):
 
         s = df.iloc[-1, :]
         DerivedDataApi().delete_hedge_fund_investor_pur_redemp(id_to_delete=id)
-        self._refresh_datas_after_updating(s.fof_id, s.investor_id, s.datetime)
+        self._refresh_datas_after_updating(s.manager_id, s.fof_id, s.investor_id, s.datetime)
 
     def investor_div_carry_add(self, datas: Dict[str, Any]):
         '''
@@ -268,7 +269,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             # 计提业绩报酬 暂不需要额外处理
             pass
         else:
-            total_share, share_separate = self._get_total_share(datas['fof_id'], datas['investor_id'])
+            total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['investor_id'])
             share_separate = share_separate.share_changed.array[-1]
             div = datas['total_dividend'] * share_separate / total_share
 
@@ -322,6 +323,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         datas : Dict[str, Any]
             数据, keys:
                 fof_id : 产品ID
+                manager_id : 管理端ID
                 datetime : 分红日期
                 event_type : 红利发放方式(现金分红/红利再投)
                 net_asset_value : 单位净值
@@ -335,7 +337,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         throw excepion if failed, or return a pd.DataFrame if succeed
         '''
 
-        total_share, share_separate = self._get_total_share(datas['fof_id'])
+        total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'])
         share_separate = share_separate.share_changed
         weight = share_separate / total_share
 
@@ -378,6 +380,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         df['share_after_trans'] = share_separate + df.share_changed
 
         df['fof_id'] = datas['fof_id']
+        df['manager_id'] = datas['manager_id']
         df['datetime'] = datas['datetime']
         df['event_type'] = datas['event_type']
         df['total_dividend'] = dividend_amount
@@ -392,6 +395,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         datas : Dict[str, Any]
             数据, keys:
                 fof_id : 产品ID
+                manager_id : 管理端ID
                 datetime : 计提日期
                 net_asset_value : 单位净值
                 acc_unit_value : 累计净值
@@ -401,17 +405,17 @@ class HedgeFundDataManager(metaclass=Singleton):
         throw excepion if failed, or return a pd.DataFrame if succeed
         '''
 
-        fof_info = BasicDataApi().get_fof_info(fof_id_list=[datas['fof_id']])
+        fof_info = BasicDataApi().get_fof_info(datas['manager_id'], fof_id_list=[datas['fof_id']])
         assert fof_info is not None, '!!!!'
         assert fof_info.shape[0] == 1, f"invalid fof id {[datas['fof_id']]}"
         fof_info = fof_info.iloc[-1, :]
 
-        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp([datas['fof_id']])
+        part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp(datas['manager_id'], [datas['fof_id']])
         assert part1 is not None, '!!!!'
 
         carry_data = []
         for investor_id in part1.investor_id.unique():
-            share_details = self._calc_share_details(fof_info, datas['fof_id'], investor_id)
+            share_details = self._calc_share_details(fof_info, datas['manager_id'], datas['fof_id'], investor_id)
             share_before_trans = pd.DataFrame(share_details).share.sum()
             carry_amount_sum = 0
             share_changed = 0
@@ -439,6 +443,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             })
         df = pd.DataFrame(carry_data)
         df['fof_id'] = datas['fof_id']
+        df['manager_id'] = datas['manager_id']
         df['datetime'] = datas['datetime']
         df['event_type'] = FOFTradeStatus.DEDUCT_REWARD
         return df
@@ -467,6 +472,9 @@ class HedgeFundDataManager(metaclass=Singleton):
         the_date = pd.to_datetime(the_date[0], infer_datetime_format=True).date()
 
         df = pd.read_excel(datas, header=4, index_col=0)
+        df = df.loc[df.index.notna(), :]
+        df = df.rename(columns={'Unnamed: 7': '成本.1', 'Unnamed: 11': '市值.1', 'Unnamed: 14': '估值增值.1'})
+        print(df)
         equity = df.at['资产净值', '市值.1']
         total_shares = df.at['实收资本', '数量']
 
@@ -542,6 +550,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             'hedge_funds_data': hedge_funds.to_json(orient='records'),
         })
         total_df = total_df.to_frame().T
+        total_df = total_df.infer_objects()
         now_df = DerivedDataApi().get_hedge_fund_custodian_data(manager_id=manager_id, fof_id_list=[fof_id])
         if now_df is not None:
             now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).astype(total_df.dtypes.to_dict())
