@@ -235,7 +235,9 @@ class HedgeFundNAVReader:
                 continue
 
             try:
-                if 'SGM473' in name:
+                if 'SLW695' in name:
+                    continue
+                elif 'SGM473' in name:
                     df = HedgeFundNAVReader._read_for_HuaChengZhiYuanNo3WithoutV(file_path)
                 elif '华澄致远三号' in name:
                     df = HedgeFundNAVReader._read_for_HuaChengZhiYuanNo3(file_path)
