@@ -1113,7 +1113,7 @@ class Calculator:
             df = df.join(_df)
             #df.loc[:,'中位数'] = df[valuation_type].rolling(window=df.shape[0], min_periods=10).median()
             #df.loc[:,'百分位'] = df[valuation_type].rolling(window=df.shape[0], min_periods=10).apply(pctrank)
-            return df.dropna()
+            return df
         except Exception as e:
             print(f'failed to get data <err_msg> {e} from derived.index_val_history')
             return False
